@@ -106,7 +106,7 @@ class LatexProject:
             copyfile(src, dest)
 
         logging.info(f"Rendering template...")
-        template = self.jinja.get_template("index.tpl")
+        template = self.jinja.get_template("index.tpl.tex")
         try:
             _, first_article, __ = self.articles[0]
             return template.render(
@@ -116,6 +116,7 @@ class LatexProject:
                 main_day=first_article.date.day,
                 main_month=first_article.date.month,
                 main_year=first_article.date.year,
+                oxalink=first_article.oxalink(self.session.site_url),
             )
         except ValueError as err:
             raise ValueError("Need at least one article") from err
